# This SRPM will build the package "R-base-gnome" (R with gnome
# support) if the macro %pkg is defined as "gnome", or R-base
# (R without gnome) if %pkg is defined as R-base.

%define ver	0.90.1
%define rel	4
%define prefix	/usr
%define pkg	base

Summary: A language for data analysis and graphics
Name: R-%{pkg}
Version: %ver
Release: %rel
Source0: ftp://cvs.r-project.org/pub/R/src/base/R-%{ver}.tgz
Patch0: R-LIBINDEX.patch
Patch1: R-refman.patch
Copyright: GPL
Group: Applications/Engineering
Packager: Martyn Plummer <plummer@iarc.fr>
URL: http://www.r-project.org
BuildRoot: /var/tmp/R-base-root
Provides: R-base
Requires: sed
ExcludeArch: sparc
Prefix: %prefix
Conflicts: R-contrib <= 1998.11.16
Conflicts: R-VR <= 5.3pl027
Obsoletes: R-gnome, R-splines

%description
A system for statistical computation and graphics. R consists of a
language plus a run-time environment with graphics, a debugger, access
to certain system functions, and the ability to run programs stored in
script files.

The design of R has been heavily influenced by two existing languages:
Becker, Chambers & Wilks' S and Sussman's Scheme. Whereas the resulting
language is very similar in appearance to S, the underlying implementation
and semantics are derived from Scheme.

%prep
%setup -q -n R-%{ver}
%patch0 -p1
%patch1 -p0

%build
export CFLAGS=$RPM_OPT_FLAGS
export FFLAGS=$RPM_OPT_FLAGS

if [ %pkg = "base-gnome" ]; then
   ./configure --prefix=${RPM_BUILD_ROOT}%{prefix} --with-gnome 
else
   ./configure --prefix=${RPM_BUILD_ROOT}%{prefix} 
fi

make 
make check
make pdf

%install
make install
install -m 755  bin/LIBINDEX ${RPM_BUILD_ROOT}%{prefix}/lib/R/bin/LIBINDEX
cp doc/manual/R-exts.pdf .

#Fix location of R_HOME in shell wrapper
#
cd ${RPM_BUILD_ROOT}/%{prefix}
sed -e "s@{R_HOME=.*@{R_HOME=%{prefix}/lib/R}@" lib/R/bin/R > bin/R
chmod 755 bin/R
cp bin/R lib/R/bin/R

# Remove package indices. These files may be changed when R "packages"
# (third-party dynamically loadable libraries with added functionality)
# are installed, so we remove them here to avoid problems with the
# verify script. They are rebuilt by the postinstall script.
#
rm -f ${RPM_BUILD_ROOT}%{prefix}/lib/R/doc/html/function.html
rm -f ${RPM_BUILD_ROOT}%{prefix}/lib/R/doc/html/packages.html
rm -f ${RPM_BUILD_ROOT}%{prefix}/lib/R/library/LibIndex

%files 
%defattr(-, root, root)
%{prefix}/bin/*
%{prefix}/man/*/*
%{prefix}/lib/R
%doc BUGS COPYING COPYRIGHTS FAQ INSTALL MIRROR-SITES NEWS
%doc PLATFORMS PROJECTS README RESOURCES 
%doc R-exts.pdf

%clean
rm -rf $RPM_BUILD_ROOT

%post 
if [ $RPM_INSTALL_PREFIX != %prefix ]; then
   cd ${RPM_INSTALL_PREFIX}
   sed -e "s@{R_HOME=.}*@{R_HOME=${RPM_INSTALL_PREFIX}/lib/R}@" lib/R/bin/R > bin/R
   chmod 755 bin/R
   cp bin/R lib/R/bin/R
fi

${RPM_INSTALL_PREFIX}/bin/R LIBINDEX

%preun 
if [ $1 = 0 ]; then
   rm -f ${RPM_INSTALL_PREFIX}/lib/R/doc/html/function.html
   rm -f ${RPM_INSTALL_PREFIX}/lib/R/doc/html/packages.html
   rm -f ${RPM_INSTALL_PREFIX}/lib/R/library/LibIndex
fi

%changelog
* Mon Feb 21 2000 Tim Powers <timp@redhat.com>
- obsoletes R-splines now.

* Tue Feb 08 2000 Tim Powers <timp@redhat.com>
- built for 6.2

* Tue Feb 08 2000 Martyn Plummer <plummer@iarc.fr>
- Writing R extensions manual in pdf format

* Wed Dec 15 1999 Martyn Plummer <plummer@iarc.fr>
- R-0.90.1. Removed Naoki's memory profile patch

* Fri Dec 3 1999 Tim Powers <timp@redhat.com>
- move configure into build section
- quiet scripts
- built for Powertools-6.2

* Mon Nov 29 1999 Martyn Plummer <plummer@iarc.fr>
- Added patch from Naoki to fix problem with memory profile.
  (will be folded in to next R version).

* Mon Nov 22 1999 Martyn Plummer <plummer@iarc.fr>
- R 0.90.0 Naoki's patch for FFT bug no longer necessary.
- Updated URL tag to www.r-project.org 

* Thu Oct 28 1999 Martyn Plummer <plummer@iarc.fr>
- RHCN is officially dead. Changed the Packager field
  back to my name and removed the Distribution field.

* Thu Oct 14 1999 Martyn Plummer <plummer@iarc.fr>
- Set CFLAGS and FFLAGS to be RPM_OPT_FLAGS. Thanks to
  Timothy H. Keitt <keitt@nceas.ucsb.edu>
- Simplified file list.

* Fri Oct 8 1999 Martyn Plummer <plummer@iarc.fr>
- Added patch from Naoki Takebayashi to fix FFT bug on Alpha
  (also found on Sparc).

* Tue Sep 7 1999 Martyn Plummer <plummer@iarc.fr>
  [R-base-0.65.0-1]
- RHOME is now R_HOME. Changed sed scripts accordingly.
- TASKS file is no longer in file list.

* Fri Jul 30 1999 Martyn Plummer <plummer@iarc.fr>
- Added patch from Alex Buerkle <cbuerkle@bio.indiana.edu>
  Allows build when $RPM_BUILD_DIR and $RPM_BUILD_ROOT are
  on different file systems.
- No C compiler optimization on Sparc.

* Mon Jul 12 1999 Martyn Plummer <plummer@iarc.fr>
- On Sparc, an egcs-g77 bug causes "make check" to fail on the line
  "eigen(cbind( 1,3:1,1:3))". This is a compiler bug which can be
  worked around by not optimizing. Added fix for Sparc

* Fri Jul 2 1999 Martyn Plummer <plummer@iarc.fr>
  [R-base-0.64.2-1]
- Alpha support fixes by Naoki Takebayashi <ntakebay@bio.indiana.edu>
  FFLAGS="-mieee -g -O2" is added for Alpha.  This flag will not be needed
  in the next release (0.65) because configure will take care of it.
  CFLAGS -O1 is dropped.
- Exclusivearch:i386 tag dropped.

* Mon Jun 29 1999 Tim Powers <timp@redhat.com>
  [R-base-0.64.1-6]
- moved changelog to end of spec
- rebuilt package for Powertools 6.1
- added ExclusiveArch: i386 and the Conflicts and Obsoletes lines

* Thu Jun 3 1999 Martyn Plummer <plummer@iarc.fr>
  [R-base-0.64.1-5]
- Builds "R-base-gnome" with GNOME support and "R-base" without.
- Dropped ncurses3 dependency.
